Description: A little bit of background about Daniel Roy Greenfeld

# About Daniel Roy Greenfeld

Daniel Roy Greenfeld

# About Me I am a [coder](https://github.com/pydanny), [author](/books), and speaker. I'm probably best known as "[pydanny](https://www.google.com/search?q=pydanny)", one of the authors of [Two Scoops of Django](/books/tech). I love to hang out with my [wife](https://audrey.feldroy.com/), play with my [daughter](/tags/uma), do [Brazilian Jiu-Jitsu](https://en.wikipedia.org/wiki/Brazilian_jiu-jitsu), write [books](/books), and read books. I track my fitness [here](/fitness) and my writing [here](/writing-stats). I am on sabbatical from [Kraken Tech](https://kraken.tech/), part of the sustainable global energy [Octopus Energy Group](https://octopusenergy.group/). There I worked toward the mission of addressing [global climate change](/tags/climate-change). - [LinkedIn](https://www.linkedin.com/in/danielfeldroy/) - [Bluesky](https://bsky.app/profile/pydanny.bsky.social) - [Twitter](https://twitter.com/pydanny) ## About this site This site is written using the [Air](https://github.com/feldroy/air) web framework. The source code is on [github](https://github.com/pydanny/daniel-blog-air). ## What about pydanny.com? That site redirects here. The reason for that is while I'm a huge fan of the Python programming language, there are other languages that I like just as much. To be forever tied to one language felt limiting, hence why I moved the site to daniel.feldroy.com and stopped using "pydanny" so much.